==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QAbstractEventDispatcher_TimerInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qabstracteventdispatcher.h>
#include <QtCore/QVariant>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QAbstractEventDispatcher_TimerInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractEventDispatcher::TimerInfo")
    QAbstractEventDispatcher::TimerInfo *_ptr = reinterpret_cast<QAbstractEventDispatcher::TimerInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new TimerInfo(int,int,Qt::TimerType)
void __qt_construct_QAbstractEventDispatcher_TimerInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimerInfo(int,int,Qt::TimerType)")
    jint id0 = __java_arguments[0].i;
    Q_UNUSED(id0)
    jint i1 = __java_arguments[1].i;
    Q_UNUSED(i1)
    jobject t2 = __java_arguments[2].l;
    Qt::TimerType __qt_t2 = qtjambi_cast<Qt::TimerType>(__jni_env, t2);
    QAbstractEventDispatcher::TimerInfo *__qt_this = new(__qtjambi_ptr) QAbstractEventDispatcher::TimerInfo(static_cast<int>(id0), static_cast<int>(i1), Qt::TimerType(__qt_t2));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QAbstractEventDispatcher::TimerInfo
void __qt_destruct_QAbstractEventDispatcher_TimerInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractEventDispatcher::TimerInfo")
    reinterpret_cast<QAbstractEventDispatcher::TimerInfo*>(ptr)->~TimerInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractEventDispatcher::TimerInfo::TimerInfo(int,int,Qt::TimerType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_initialize_1native__Lio_qt_core_QAbstractEventDispatcher_00024TimerInfo_2IILio_qt_core_Qt_00024TimerType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint id0,
 jint i1,
 jobject t2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractEventDispatcher::TimerInfo::TimerInfo(int,int,Qt::TimerType)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].i = id0;
        arguments[1].i = i1;
        arguments[2].l = t2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractEventDispatcher_TimerInfo_0, sizeof(QAbstractEventDispatcher::TimerInfo), typeid(QAbstractEventDispatcher::TimerInfo), false, &deleter_QAbstractEventDispatcher_TimerInfo, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAbstractEventDispatcher::TimerInfo::operator==(QAbstractEventDispatcher::TimerInfo,QAbstractEventDispatcher::TimerInfo)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_equals_1native_1cref_1QAbstractEventDispatcher_1TimerInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID v21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractEventDispatcher::TimerInfo::operator==(QAbstractEventDispatcher::TimerInfo,QAbstractEventDispatcher::TimerInfo)", __qt_this)
        const QAbstractEventDispatcher::TimerInfo& __qt_v21 = QtJambiAPI::objectReferenceFromNativeId<QAbstractEventDispatcher::TimerInfo>(__jni_env, v21);
        __java_return_value = (*__qt_this) == __qt_v21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_setInterval_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint interval0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->interval = static_cast<int>(interval0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_interval_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->interval;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_setTimerId_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timerId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->timerId = static_cast<int>(timerId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_timerId_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->timerId;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_setTimerType_1native_1cref_1Qt_1TimerType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timerType0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::TimerType __qt_timerType0 = qtjambi_cast<Qt::TimerType>(__jni_env, timerType0);
        __qt_this->timerType = Qt::TimerType(__qt_timerType0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_timerType_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::TimerType&  __qt_value = __qt_this->timerType;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCustomStructors)
void* custom_constructor_QAbstractEventDispatcher_TimerInfo(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QAbstractEventDispatcher::TimerInfo* copy = static_cast<const QAbstractEventDispatcher::TimerInfo*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QAbstractEventDispatcher::TimerInfo(copy->timerId, copy->interval, copy->timerType);
    }else{
        return new(placement) QAbstractEventDispatcher::TimerInfo(0, 0, Qt::PreciseTimer);
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QAbstractEventDispatcher_TimerInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QAbstractEventDispatcher::TimerInfo>("QAbstractEventDispatcher::TimerInfo", "io/qt/core/QAbstractEventDispatcher$TimerInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractEventDispatcher_TimerInfo, {
        ConstructorInfo(&__qt_construct_QAbstractEventDispatcher_TimerInfo_0, "IILio/qt/core/Qt$TimerType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractEventDispatcher_TimerInfo);
    registerMetaType<QAbstractEventDispatcher::TimerInfo>("QAbstractEventDispatcher::TimerInfo", &custom_constructor_QAbstractEventDispatcher_TimerInfo);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QAbstractEventDispatcher_TimerInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qabstracteventdispatcher.h>
#include <QtCore/QVariant>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QAbstractEventDispatcher_TimerInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractEventDispatcher::TimerInfo")
    QAbstractEventDispatcher::TimerInfo *_ptr = reinterpret_cast<QAbstractEventDispatcher::TimerInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new TimerInfo(QAbstractEventDispatcher::TimerInfo)
void __qt_construct_QAbstractEventDispatcher_TimerInfo_cref_QAbstractEventDispatcher_TimerInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimerInfo(QAbstractEventDispatcher::TimerInfo)")
    jobject other0 = __java_arguments[0].l;
    const QAbstractEventDispatcher::TimerInfo& __qt_other0 = qtjambi_cast<const QAbstractEventDispatcher::TimerInfo& >(__jni_env, other0);
    QAbstractEventDispatcher::TimerInfo *__qt_this = new(__qtjambi_ptr) QAbstractEventDispatcher::TimerInfo(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QAbstractEventDispatcher::TimerInfo::TimerInfo(QAbstractEventDispatcher::TimerInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_initialize_1native__Lio_qt_core_QAbstractEventDispatcher_00024TimerInfo_2Lio_qt_core_QAbstractEventDispatcher_00024TimerInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractEventDispatcher::TimerInfo::TimerInfo(QAbstractEventDispatcher::TimerInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractEventDispatcher_TimerInfo_cref_QAbstractEventDispatcher_TimerInfo, sizeof(QAbstractEventDispatcher::TimerInfo), typeid(QAbstractEventDispatcher::TimerInfo), false, &deleter_QAbstractEventDispatcher_TimerInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new TimerInfo(int,int,Qt::TimerType)
void __qt_construct_QAbstractEventDispatcher_TimerInfo_int_int_Qt_TimerType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimerInfo(int,int,Qt::TimerType)")
    jint id0 = __java_arguments[0].i;
    Q_UNUSED(id0)
    jint i1 = __java_arguments[1].i;
    Q_UNUSED(i1)
    jobject t2 = __java_arguments[2].l;
    Qt::TimerType __qt_t2 = qtjambi_cast<Qt::TimerType>(__jni_env, t2);
    QAbstractEventDispatcher::TimerInfo *__qt_this = new(__qtjambi_ptr) QAbstractEventDispatcher::TimerInfo(static_cast<int>(id0), static_cast<int>(i1), Qt::TimerType(__qt_t2));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QAbstractEventDispatcher::TimerInfo::TimerInfo(int,int,Qt::TimerType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_initialize_1native__Lio_qt_core_QAbstractEventDispatcher_00024TimerInfo_2IILio_qt_core_Qt_00024TimerType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint id0,
 jint i1,
 jobject t2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractEventDispatcher::TimerInfo::TimerInfo(int,int,Qt::TimerType)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].i = id0;
        arguments[1].i = i1;
        arguments[2].l = t2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractEventDispatcher_TimerInfo_int_int_Qt_TimerType, sizeof(QAbstractEventDispatcher::TimerInfo), typeid(QAbstractEventDispatcher::TimerInfo), false, &deleter_QAbstractEventDispatcher_TimerInfo, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAbstractEventDispatcher::TimerInfo
void __qt_destruct_QAbstractEventDispatcher_TimerInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractEventDispatcher::TimerInfo")
    reinterpret_cast<QAbstractEventDispatcher::TimerInfo*>(ptr)->~TimerInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractEventDispatcher::TimerInfo::operator==(QAbstractEventDispatcher::TimerInfo,QAbstractEventDispatcher::TimerInfo)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_equals_1native_1cref_1QAbstractEventDispatcher_1TimerInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID v21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractEventDispatcher::TimerInfo::operator==(QAbstractEventDispatcher::TimerInfo,QAbstractEventDispatcher::TimerInfo)", __qt_this)
        const QAbstractEventDispatcher::TimerInfo& __qt_v21 = QtJambiAPI::objectReferenceFromNativeId<QAbstractEventDispatcher::TimerInfo>(__jni_env, v21);
        __java_return_value = (*__qt_this) == __qt_v21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_setInterval_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint interval0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->interval = static_cast<int>(interval0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_interval_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->interval;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_setTimerId_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timerId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->timerId = static_cast<int>(timerId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_timerId_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->timerId;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_setTimerType_1native_1cref_1Qt_1TimerType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timerType0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::TimerType __qt_timerType0 = qtjambi_cast<Qt::TimerType>(__jni_env, timerType0);
        __qt_this->timerType = Qt::TimerType(__qt_timerType0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_timerType_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::TimerType&  __qt_value = __qt_this->timerType;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCustomStructors)
void* custom_constructor_QAbstractEventDispatcher_TimerInfo(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QAbstractEventDispatcher::TimerInfo* copy = static_cast<const QAbstractEventDispatcher::TimerInfo*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QAbstractEventDispatcher::TimerInfo(copy->timerId, copy->interval, copy->timerType);
    }else{
        return new(placement) QAbstractEventDispatcher::TimerInfo(0, 0, Qt::PreciseTimer);
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QAbstractEventDispatcher_00024TimerInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QAbstractEventDispatcher::TimerInfo *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractEventDispatcher::TimerInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QAbstractEventDispatcher_TimerInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QAbstractEventDispatcher::TimerInfo>("QAbstractEventDispatcher::TimerInfo", "io/qt/core/QAbstractEventDispatcher$TimerInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractEventDispatcher_TimerInfo, {
        ConstructorInfo(&__qt_construct_QAbstractEventDispatcher_TimerInfo_cref_QAbstractEventDispatcher_TimerInfo, "Lio/qt/core/QAbstractEventDispatcher$TimerInfo;")
       ,ConstructorInfo(&__qt_construct_QAbstractEventDispatcher_TimerInfo_int_int_Qt_TimerType, "IILio/qt/core/Qt$TimerType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractEventDispatcher_TimerInfo);
    registerMetaType<QAbstractEventDispatcher::TimerInfo>("QAbstractEventDispatcher::TimerInfo", &custom_constructor_QAbstractEventDispatcher_TimerInfo);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
